@@ -427,8 +427,6 @@ class Lattice:
             return tuple(int(x) for x in round_func(np.round(position / grid_step, 10)))
 
         grid_size = to_grid(lattice, np.array([1, 1, 1]), np.ceil)
-        print(grid_size)
-        print(np.round(lattice.vectors @ np.array([1, 1, 1]) / grid_step, 10))
 
         grid = [[[[] for _ in range(grid_size[2])]
                      for _ in range(grid_size[1])]
