@@ -1,26 +1,41 @@
 from crystally.core.lattice import *
 
 
-def interpolate_lattices(lattice1: Lattice, lattice2: Lattice, weighting=0.5):
-    """ Linearly interpolate the atom list two lattices and return new lattice. Mind that the two lattices need to be
-    sorted first!
+def make_neb(lattice1: Lattice, lattice2: Lattice, image_numbers=1, tolerance=None):
+    """ Linearly interpolate the atom list two lattices and new lattices according to the number of images.
 
     :param lattice1: first :class:`~crystally.core.lattice.Lattice`
     :param lattice2: second :class:`~crystally.core.lattice.Lattice`
-    :param weighting: weighting between the two lattices. With weighting=0 the first, with weighting=1.0 the second
-    lattice is returned. With weighting=0.5 (default value) every new atom position lies exactly between the ones of
-    the provided lattices.
-    :return: new interpolated :class:`~crystally.core.lattice.Lattice`
+    :param image_numbers: number of images for the NEB algorithm
+    :param tolerance: the tolerance in angstrom which is used to compare atoms and sort the lattices
+    :return: list of new :class:`~crystally.core.lattice.Lattice`. This includes the lattices for the initial and
+    final state.
     """
+
     if len(lattice1.atoms) != len(lattice2.atoms):
         raise ValueError("lattices must have the same number of atoms!")
 
-    new_lattice = Lattice(vectors=lattice1.vectors, atoms=[])
-    for atom1, atom2 in zip(lattice1, lattice2):
-        new_position = atom1.position + atom1.position.diff(atom2.position)*weighting
-        new_atom = Atom(element=atom1.element, position=new_position, sublattice=atom1.sublattice)
-        new_lattice.atoms.append(new_atom)
-    return new_lattice
+    # make copies of original lattices
+    lattice1 = Lattice.from_lattice(lattice1)
+    lattice2 = Lattice.from_lattice(lattice2)
+
+    # sort lattices to each other
+    lattice1.sort(lattice2, tolerance=tolerance)
+    lattice2.sort(lattice1, tolerance=tolerance)
+
+    neb_lattices = [lattice1]
+
+    # the weighting for the interpolation is determined by the number of images
+    for weighting in np.linspace(0, 1, image_numbers+2)[1:image_numbers+1]:
+        new_lattice = Lattice(vectors=lattice1.vectors, atoms=[])
+        for atom1, atom2 in zip(lattice1, lattice2):
+            new_position = atom1.position + atom1.position.diff(atom2.position) * weighting
+            new_atom = Atom(element=atom1.element, position=new_position, sublattice=atom1.sublattice)
+            new_lattice.atoms.append(new_atom)
+        neb_lattices.append(new_lattice)
+
+    neb_lattices.append(lattice2)
+    return neb_lattices
 
 
 def get_element_number_list(lattice):
